@@ -1,4 +1,4 @@
-run.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, burnin = 4000, sample = 10000, adapt=1000, datalist=NA, initlist=NA, jags = runjags.getOption('jagspath'), silent.jags = FALSE, summarise = TRUE, confidence=0.95, plots = summarise, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, modules=runjags.getOption('modules'), factories=runjags.getOption('factories'), thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, monitor.pd.i = FALSE, monitor.popt = FALSE, check.conv = summarise, keep.jags.files = FALSE, tempdir=runjags.getOption('tempdir'), jags.refresh=0.1, batch.jags=silent.jags, method=runjags.getOption('method'), method.options=list()){
+run.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, burnin = 4000, sample = 10000, adapt=1000, datalist=NA, initlist=NA, jags = runjags.getOption('jagspath'), silent.jags = runjags.getOption('silent.jags'), summarise = TRUE, confidence=0.95, plots = runjags.getOption('predraw.plots') && summarise, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, modules=runjags.getOption('modules'), factories=runjags.getOption('factories'), thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, monitor.pd.i = FALSE, monitor.popt = FALSE, check.conv = summarise, keep.jags.files = FALSE, tempdir=runjags.getOption('tempdir'), jags.refresh=0.1, batch.jags=silent.jags, method=runjags.getOption('method'), method.options=list()){
 	
 	# Translate monitor.pd/popt/pd.i/deviance/check.conv (legacy code):
 	monitor <- c(monitor, if(monitor.deviance) "deviance", if(monitor.pd) "pd", if(monitor.popt) "popt", if(monitor.pd.i) "pd.i")
@@ -7,7 +7,7 @@ run.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, burn
 		summarise <- check.conv
 	}
 	if(any(c(monitor.deviance, monitor.pd, monitor.popt, monitor.pd.i))) warning("Use of the 'monitor.deviance', 'monitor.pd', 'monitor.popt' and 'monitor.pdi' arguments is deprecated - add the special variables 'dic', 'deviance', 'pd', 'popt' or 'pd.i' to the 'monitor' argument instead", call.=FALSE)
-		
+
 	method <- getrunjagsmethod(method)
 	obj <- setup.jagsfile(model=model, datalist=datalist, initlist=initlist, n.chains=n.chains, data=data, inits=inits, monitor=monitor, modules=modules, factories=factories, jags=jags, call.setup=TRUE, method=method)
 	
@@ -26,7 +26,7 @@ run.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, burn
 }
 
 
-autorun.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, startburnin = 4000, startsample = 10000, datalist=NA, initlist=NA, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, modules=runjags.getOption('modules'), factories=runjags.getOption('factories'), raftery.options = list(), crash.retry=1, summarise = TRUE, confidence=0.95, plots = summarise, thin.sample = FALSE, jags = runjags.getOption('jagspath'), silent.jags = FALSE, interactive=FALSE, max.time=Inf, adaptive=1000, thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, tempdir=runjags.getOption('tempdir'), jags.refresh=0.1, batch.jags=silent.jags, method=runjags.getOption('method'), method.options=list()){
+autorun.jags <- function(model, monitor = NA, data=NA, n.chains=NA, inits = NA, startburnin = 4000, startsample = 10000, datalist=NA, initlist=NA, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, modules=runjags.getOption('modules'), factories=runjags.getOption('factories'), raftery.options = list(), crash.retry=1, summarise = TRUE, confidence=0.95, plots = runjags.getOption('predraw.plots') && summarise, thin.sample = FALSE, jags = runjags.getOption('jagspath'), silent.jags = runjags.getOption('silent.jags'), interactive=FALSE, max.time=Inf, adaptive=1000, thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, tempdir=runjags.getOption('tempdir'), jags.refresh=0.1, batch.jags=silent.jags, method=runjags.getOption('method'), method.options=list()){
 
 	# Translate monitor.pd and deviance (legacy code):
 	monitor <- c(monitor, if(monitor.deviance) "deviance", if(monitor.pd) "pd")
